@@ -75,28 +75,31 @@ def import_content(session, repo, commitevery=10):
 
     `repo` is the cubicweb repository (not a vcs repository)
     """
-    for repoentity in session.execute(
+    for vcsrepo in session.execute(
         'Any X,T,U,P,L,SP,E WHERE X is Repository, '
         'X type T, X source_url U, X path P, X local_cache L, '
         'X subpath SP, X encoding E').entities():
-        # give a change to threads waiting for a pool
-        session.set_pool()
         try:
-            repohdlr = repository_handler(repoentity)
+            repohdlr = repository_handler(vcsrepo)
         except VCSException, ex:
             repo.error(str(ex))
             continue
+        import_vcsrepo_content(session, repohdlr, vcsrepo, commitevery=10)
+
+
+def import_vcsrepo_content(session, repohdlr, vcsrepo, commitevery=10):
+    """synchronize content of given vcs repository"""
+    try:
+        repohdlr.import_content(vcsrepo, commitevery)
+        session.commit()
+    except:
         try:
-            repohdlr.import_content(repoentity, commitevery)
-            session.commit()
+            title = vcsrepo.dc_title()
         except:
-            try:
-                title = repoentity.dc_title()
-            except:
-                title = str(repoentity)
-            repoentity.exception(
-                'error while importing content for vcs repo %s', title)
-            session.rollback()
+            title = str(vcsrepo)
+        repohdlr.exception(
+            'error while importing content for vcs repo %s', title)
+        session.rollback()
 
 
 def set_at_revision(session, reid, safetybelt=False):
