@@ -127,17 +127,32 @@ class ServerStartupHook(Hook):
                     'R type RT, R local_cache RLC, '
                     'R source_url RSU, R path RP')
                 for vcsrepo in reposrset.entities():
+                    # XXX when this will be available, filter according to
+                    # source in the rql query instead of the test below
+                    # used to discard repository from external sources
+                    if vcsrepo.cw_metainformation()['source']['uri'] != 'system':
+                        continue
                     try:
-                        bridge.repository_handler(vcsrepo).pull_or_clone_cache(
-                            vcsrepo.source_url)
+                        repohdlr = bridge.repository_handler(vcsrepo)
+                    except bridge.VCSException, ex:
+                        repo.error(str(ex))
+                        continue
                     except Exception:
-                        self.exception(
+                        repo.exception('error while retreiving handler for %s',
+                                       vcsrepo.eid)
+                        continue
+                    try:
+                        repohdlr.pull_or_clone_cache(vcsrepo.source_url)
+                    except Exception:
+                        repohdlr.exception(
                             'error while updating local cache of repository %s',
                             vcsrepo.eid)
                     # give other threads a chance to run
                     session.set_pool()
-                if repo.config['repository-import']:
-                    bridge.import_content(session, repo, repo.config.get('check-revision-commit-every', 1))
+                    if repo.config['repository-import']:
+                        bridge.import_vcsrepo_content(
+                            session, repohdlr, vcsrepo,
+                            commitevery=repo.config.get('check-revision-commit-every', 1))
             finally:
                 session.close()
 
