@@ -19,6 +19,13 @@ from cubes.vcsfile import repo, bridge
 
 _DELETED = object()
 
+def monkeypatch_mercurial_url():
+    from mercurial.url import httphandler
+    if hasattr(httphandler, '__del__'):
+        del httphandler.__del__
+monkeypatch_mercurial_url()
+
+
 class vcsfile_ui(ui.ui):
     """ redirect output to cubicweb log """
     def __init__(self, loggable):
