@@ -13,7 +13,8 @@ from yams.buildobjs import (DEFAULT_ATTRPERMS,
 from cubicweb.schema import RRQLExpression
 
 PRIVATE_ATTRPERMS = DEFAULT_ATTRPERMS.copy()
-PRIVATE_ATTRPERMS['read'] = ('managers', 'users')
+PRIVATE_ATTRPERMS['read'] = ('managers',)
+PRIVATE_ATTRPERMS['update'] = ('managers',)
 
 RO_ATTRPERMS = DEFAULT_ATTRPERMS.copy()
 RO_ATTRPERMS['update'] = ()
