@@ -1,9 +1,11 @@
+from os.path import join, abspath
 from logilab.common.decorators import clear_cache
+from cubicweb import ValidationError
 from cubicweb.devtools.testlib import CubicWebTC
-from utils import VCSFileTC
+from utils import VCSFileTC, HERE
 
 class BranchHeadsTC(VCSFileTC):
-    repo_path = u'testrepohg_branches'
+    _repo_path = u'testrepohg_branches'
     repo_type = u'mercurial'
 
     def rev(self, file, *args):
@@ -41,14 +43,39 @@ class BranchHeadsTC(VCSFileTC):
 class RepositoryTC(CubicWebTC):
     def test_repo_path_security(self):
         req = self.request()
-        vcsrepo = req.create_entity('Repository', path=u'whatever', type=u'mercurial')
+        path = unicode(abspath(join(HERE, 'whatever')))
+        vcsrepo = req.create_entity('Repository',
+                                    path=path, type=u'mercurial')
         req.cnx.commit()
-        self.assertEquals(vcsrepo.dc_title(), 'mercurial:whatever')
+        self.assertEquals(vcsrepo.dc_title(),
+                          u'mercurial:%s' % path)
         self.login('anon')
         req = self.request()
         vcsrepo = req.execute('Repository X').get_entity(0, 0)
         self.assertEquals(vcsrepo.dc_title(), 'mercurial repository #%s' % vcsrepo.eid)
 
+    def test_unmodifiable_attrs(self):
+        req = self.request()
+        self.assertRaises(ValidationError, req.create_entity, 'Repository',
+                          source_url=u"http://myrepo.ru",
+                          type=u'mercurial')
+        req.cnx.rollback()
+        req = self.request()
+        repo = req.create_entity('Repository', type=u'mercurial',
+                                 path=unicode(abspath(join(HERE, 'whatever'))))
+        req.cnx.commit()
+        self.assertRaises(ValidationError, repo.set_attributes, path=u'new')
+        self.assertRaises(ValidationError, repo.set_attributes, type=u'mercurial')
+        self.assertRaises(ValidationError, repo.set_attributes, source_url=u'http://myrepo.fr')
+
+    def test_source_url_format(self):
+        req = self.request()
+        self.assertRaises(ValidationError, req.create_entity, 'Repository',
+                          path=u'whatever', type=u'mercurial')
+        self.assertRaises(ValidationError, req.create_entity, 'Repository',
+                          source_url=u'whatever', type=u'mercurial')
+
+
 if __name__ == '__main__':
     from logilab.common.testlib import unittest_main
     unittest_main()
