@@ -5,6 +5,7 @@ logging.basicConfig(level=logging.CRITICAL)
 
 from logilab.common.testlib import unittest_main
 from cubicweb import ValidationError
+from cubes.vcsfile import bridge
 
 from utils import VCSFileTC
 
@@ -102,6 +103,12 @@ class SVNRepoTC(VCSFileTC):
         self.assertEquals(res[1], [u'toto.txt'])
         self.assertEquals(res[2], [u'tutu.txt'])
 
+    def test_anon_access_data(self):
+        bridge._REPOHDLRS.clear()
+        self.login('anon')
+        res = self.execute('VersionContent X LIMIT 1').get_entity(0, 0)
+        self.failUnless(res.data)
+        self.failUnless(res.data.getvalue())
 
 class SVNPartRepoTC(VCSFileTC):
     repo_type = u'subversion'
@@ -176,11 +183,10 @@ class HGRepoTC(SVNRepoTC):
 
 
     def test_error_update_repo(self):
-        self.assertRaises(ValidationError,
-                          self.execute, 'SET X path "/tmp/pouet" WHERE X is Repository')
         self.assertRaises(ValidationError,
                           self.execute, 'SET X type "subversion" WHERE X is Repository')
 
+
 class HGPartRepoTC(SVNPartRepoTC):
     repo_type = u'mercurial'
     _repo_path = u'testrepohg'
@@ -224,10 +230,14 @@ class HGCachedRepoTC(VCSFileTC):
 
     def test_cache_mgmt(self):
         self.session.repo = self.repo
-        self.failIf(not osp.isdir(self.vcsrepo.local_cache))
+        self.failIf(osp.isabs(self.vcsrepo.local_cache))
+        cachedir = osp.join(self.config['local-repo-cache-root'],
+                            self.vcsrepo.local_cache)
+        self.failUnless(osp.isabs(cachedir))
+        self.failUnless(osp.isdir(cachedir))
         self.execute('DELETE Repository R WHERE R eid %(r)s', {'r': self.vcsrepo.eid})
         self.commit()
-        self.failIf(osp.isdir(self.vcsrepo.local_cache))
+        self.failIf(osp.isdir(cachedir))
 
 if __name__ == '__main__':
     unittest_main()
